@@ -288,24 +288,42 @@ def _detect_vcs(expected_vcs: Optional[Vcs] = None) -> Vcs:
         ]
     )
 
+    dubious_ownership_flag = "detected dubious ownership"
+    dubious_ownership_error = "Detected Git repository, but failed because of dubious ownership"
+
     if expected_vcs:
         command = checks[expected_vcs]
         program = command.split()[0]
         if not shutil.which(program):
             raise RuntimeError("Unable to find '{}' program".format(program))
-        code, _ = _run_cmd(command, codes=[])
+        code, msg = _run_cmd(command, codes=[])
         if code != 0:
+            if expected_vcs == Vcs.Git and dubious_ownership_flag in msg:
+                raise RuntimeError(dubious_ownership_error)
             raise RuntimeError(
                 "This does not appear to be a {} project".format(expected_vcs.value.title())
             )
         return expected_vcs
     else:
+        disproven = []
+        unavailable = []
         for vcs, command in checks.items():
             if shutil.which(command.split()[0]):
-                code, _ = _run_cmd(command, codes=[])
+                code, msg = _run_cmd(command, codes=[])
                 if code == 0:
                     return vcs
-        raise RuntimeError("Unable to detect version control system.")
+                elif vcs == Vcs.Git and dubious_ownership_flag in msg:
+                    raise RuntimeError(dubious_ownership_error)
+                disproven.append(vcs.name)
+            else:
+                unavailable.append(vcs.name)
+
+        error_parts = ["Unable to detect version control system."]
+        if disproven:
+            error_parts.append("Checked: {}.".format(", ".join(disproven)))
+        if unavailable:
+            error_parts.append("Not installed: {}.".format(", ".join(unavailable)))
+        raise RuntimeError(" ".join(error_parts))
 
 
 def _detect_vcs_from_archival() -> Optional[Vcs]:
@@ -732,12 +750,19 @@ class Version:
         :param pattern: Regular expression matched against the version.
             Refer to `from_any_vcs` for more info.
         """
+        normalized = version
+        if not version.startswith("v") and pattern in [VERSION_SOURCE_PATTERN, Pattern.Default]:
+            normalized = "v{}".format(version)
+
         try:
-            normalized = version
-            if not version.startswith("v") and pattern in [VERSION_SOURCE_PATTERN, Pattern.Default]:
-                normalized = "v{}".format(version)
             matched_pattern = _match_version_pattern(pattern, [normalized], True)
         except ValueError:
+            replaced = re.sub(r"(\.post(\d+)\.dev\d+)", r".dev\2", version, 1)
+            if replaced != version:
+                alt = Version.parse(replaced, pattern)
+                if alt.base != replaced:
+                    return alt
+
             return cls(version)
 
         base = matched_pattern.base
@@ -785,6 +810,10 @@ class Version:
         if tagged_metadata is not None and tagged_metadata.strip() == "":
             tagged_metadata = None
 
+        if stage is not None and stage[0] == "dev" and stage[1] is not None:
+            distance += stage[1]
+            stage = None
+
         return cls(
             base,
             stage=stage,
@@ -795,7 +824,7 @@ class Version:
             epoch=epoch,
         )
 
-    def bump(self, index: int = -1) -> "Version":
+    def bump(self, index: int = -1, increment: int = 1) -> "Version":
         """
         Increment the version.
 
@@ -807,16 +836,17 @@ class Version:
             the left side and count up from 0, while negative numbers start from
             the right side and count down from -1.
             Only has an effect when the base is bumped.
+        :param increment: By how much to increment the relevant position. Default: 1.
         :return: Bumped version.
         """
         bumped = copy.deepcopy(self)
         if bumped.stage is None:
-            bumped.base = bump_version(bumped.base, index)
+            bumped.base = bump_version(bumped.base, index, increment)
         else:
             if bumped.revision is None:
                 bumped.revision = 2
             else:
-                bumped.revision = bumped.revision + 1
+                bumped.revision += increment
         return bumped
 
     @classmethod
@@ -1932,7 +1962,7 @@ def serialize_pvp(base: str, metadata: Optional[Sequence[Union[str, int]]] = Non
     return serialized
 
 
-def bump_version(base: str, index: int = -1) -> str:
+def bump_version(base: str, index: int = -1, increment: int = 1) -> str:
     """
     Increment one of the numerical positions of a version.
 
@@ -1942,10 +1972,11 @@ def bump_version(base: str, index: int = -1) -> str:
         This follows Python indexing rules, so positive numbers start from
         the left side and count up from 0, while negative numbers start from
         the right side and count down from -1.
+    :param increment: By how much the `index` needs to increment. Default: 1.
     :return: Bumped version.
     """
     bases = [int(x) for x in base.split(".")]
-    bases[index] += 1
+    bases[index] += increment
 
     limit = 0 if index < 0 else len(bases)
     i = index + 1
